const gl_iEntriesMax = 500;
const gl_iDelayMax = 5000;
const gl_iDelayMin = 1000;
const gl_iDelayStep = 500;
const gl_reDTBegin = /^\d{8}\s\d{6}/;
var gl_iLastId = NaN;
var gl_timerId = NaN;
var gl_iLevel = NaN;
var gl_strCondModules = "";
var gl_strCondText = "";
var gl_fPause = false;
var gl_fCondStore = false;
var gl_iDelay = 3000;
var gl_fDate = false;

function _updateLog()
{
  const elLV = document.getElementById( "log-entries" );

  if ( !elLV )
    return;

  strReq = "ajax_log?max=" + gl_iEntriesMax;

  if ( gl_fCondStore ) {
    strReq += "&store=1";
    gl_fCondStore = false;
  }

  if ( !isNaN( gl_iLevel ) )
    strReq += "&level=" + gl_iLevel;

  if ( gl_strCondModules != "" )
    strReq += "&modules=" + encodeURIComponent( gl_strCondModules );

  if ( gl_strCondText != "" )
    strReq += "&text=" + encodeURIComponent( gl_strCondText );

  if ( !isNaN( gl_iLastId ) )
    strReq += "&stop-id=" + gl_iLastId;

  utilAJAX( strReq,
    function(xmlRoot) {
      const elCont = document.getElementById( "log-entries__cont" );
      const xmlLog = xmlRoot.firstChild;
      var iEntries = elCont.childNodes.length;
      var elE;

      if ( xmlLog.getAttribute( "missing-entries" ) == "1" ) {
        elE = document.createElement( "div" );
        elE.appendChild( document.createTextNode( "...missing entries..." ) );
        elCont.insertBefore( elE, elCont.firstChild );
      }

      gl_iDelay += gl_iDelayStep;
      if ( gl_iDelay > gl_iDelayMax ) gl_iDelay = gl_iDelayMax;

      for(xmlE of xmlLog.childNodes) {
        if ( xmlE.nodeType != 1 || xmlE.nodeName != "e" )
          continue;

        var strE = utilGetNodeText( xmlE );

        // Delete unnecessary old entries
        while( iEntries >= gl_iEntriesMax ) {
          elCont.removeChild( elCont.lastChild );
          iEntries--;
        }

        // Create element for the new entry

        elE = document.createElement( "div" );
        elE.classList.add( "log-entries__cont__entry" );

        if ( gl_reDTBegin.test( strE ) ) {
          /* Date and time */
          var elDT = document.createElement( "span" );
          elDT.appendChild( document.createTextNode( strE.slice(0,4) + "-" + strE.slice(4,6) + "-" + strE.slice(6,8) ) );
          if ( !gl_fDate ) elDT.classList.add( "invisible" );
          elE.appendChild( elDT );

          elDT = document.createElement( "span" );
          elDT.appendChild( document.createTextNode( strE.slice(9,11) + ":" + strE.slice(11,13) + ":" + strE.slice(13,15) ) );
          elE.appendChild( elDT );
          strE = strE.slice(16);
        }
        elE.appendChild( document.createTextNode( strE ) );

        // Insert new element at the beginning
        elCont.insertBefore( elE, elCont.firstChild );

        iEntries++;
        gl_iDelay = gl_iDelayMin;
      }

      gl_iLastId = parseInt( xmlLog.getAttribute( "last-id" ) );
      if ( !gl_fPause )
        gl_timerId = setTimeout( _updateLog, gl_iDelay );
    },  // function(xmlRoot)

    function(iStatus, strError) {
      gl_iDelay = gl_iDelayMax;
      if ( !gl_fPause )
        gl_timerId = setTimeout( _updateLog, gl_iDelay );
      return true;
    }
  );  // utilAJAX()
}


function _setPause(fPause) {
  const elPauseBtn = document.getElementById( "log-entries__pause" );

  if ( fPause ) {
    if ( !isNaN( gl_timerId ) ) { clearTimeout( gl_timerId ); gl_timerId = NaN; }
    elPauseBtn.value = "Resume";
  } else {
    _updateLog();
    elPauseBtn.value = "Pause";
  }
  gl_fPause = fPause;
}

function _selTab(fFilter) {
  const elLogFilter = document.getElementById( "log-filter" );
  const elLogEntries = document.getElementById( "log-entries" );
  const elTabFilter = document.getElementById( "tab-list__filter" );
  const elTabEntries = document.getElementById( "tab-list__entries" );

  (fFilter ? elLogFilter : elLogEntries).classList.remove( "invisible" );
  (fFilter ? elLogEntries : elLogFilter).classList.add( "invisible" );
  (fFilter ? elTabFilter : elTabEntries).classList.add( "tab-list__item_selected" );
  (fFilter ? elTabEntries : elTabFilter).classList.remove( "tab-list__item_selected" );
  _setPause( fFilter );
}

function _readFormFilter() {
  const strText = document.getElementById( "log-form__text" ).value;
  const aelCB = document.querySelectorAll( "input[id^='log-form__mod-']" );
  const elSelLevel = document.getElementById( "log-form__level" );

  // Read conditions from the form into global variables
  gl_strCondText = strText;
  gl_iLevel = elSelLevel.options[elSelLevel.selectedIndex].value;
  gl_strCondModules = "";
  for(var i=0; i<aelCB.length; i++) {
    if ( aelCB[i].checked )
      gl_strCondModules += aelCB[i].id.slice(14) + " ";
  }
  // "store=1" will be set for the next AJAX request
  gl_fCondStore = true;
  // All entries will be re-read to apply the filter conditions
  gl_iLastId = NaN;
  // Remove all collected entries
  utilRemoveAllChildren( document.getElementById( "log-entries__cont" ) );
}


window.addEventListener( "load", function() {
  const elLogFilter = document.getElementById( "log-filter" );
  const elPauseBtn = document.getElementById( "log-entries__pause" );
  const elDateCB = document.getElementById( "log-entries__show-date-cb" );

  elPauseBtn.addEventListener( "click", function(e) { _setPause( !gl_fPause); }, true );
  elLogFilter.onsubmit = function() {
    _readFormFilter();
    _selTab( false );
    return false;
  }

  document.getElementById( "tab-list__filter" ).addEventListener( "click", function(e) {
    _selTab( true );
    e.preventDefault();
  } );

  document.getElementById( "tab-list__entries" ).addEventListener( "click", function(e) {
    _readFormFilter();
    _selTab( false );
    e.preventDefault();
  } );

  elDateCB.checked = gl_fDate;
  elDateCB.addEventListener( "change", function(e) {
    const elCont = document.getElementById( "log-entries__cont" );
    const aelDate = elCont.querySelectorAll( ".log-entries__cont__entry span:first-child" );

    gl_fDate = elDateCB.checked;
    for(elDate of aelDate)
      if ( gl_fDate ) elDate.classList.remove( "invisible" );
      else elDate.classList.add( "invisible" );
  } );

  _selTab( true );
} );
